/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import type {Options} from 'yargs';

export declare function run(
  maybeArgv?: Array<string>,
  project?: string,
): Promise<void>;

export declare const yargsOptions: {
  [key: string]: Options;
};

export {};
